public inbox for gcc-bugs@sourceware.org
help / color / mirror / Atom feed
* [Bug c++/40074]  New: Compile failure in ocrad-0.18
@ 2009-05-08 20:16 ronis at ronispc dot chem dot mcgill dot ca
  2009-05-08 20:17 ` [Bug c++/40074] " ronis at ronispc dot chem dot mcgill dot ca
                   ` (17 more replies)
  0 siblings, 18 replies; 19+ messages in thread
From: ronis at ronispc dot chem dot mcgill dot ca @ 2009-05-08 20:16 UTC (permalink / raw)
  To: gcc-bugs

I;m running gcc-4.4.0 (built with default optimization flags, but with
additional optimizations) and was testing it on ocrad-0.18 (admittedly with
lots of optimization):  I get


g++  -march=pentium4 -msse2 -mfpmath=sse -O3 -ffast-math -funroll-loops
-fomit-frame-pointer -floop-interchange -floop-strip-mine -floop-block -c -o
track.o track.cc
track.cc: In member function 'void Track::set_track(const
std::vector<Rectangle, std::allocator<Rectangle> >&)':
track.cc:219: internal compiler error: in vect_get_vec_def_for_operand, at
tree-vect-transform.c:1999

I'll attach the preprocessed source separately.


-- 
           Summary: Compile failure in ocrad-0.18
           Product: gcc
           Version: unknown
            Status: UNCONFIRMED
          Severity: normal
          Priority: P3
         Component: c++
        AssignedTo: unassigned at gcc dot gnu dot org
        ReportedBy: ronis at ronispc dot chem dot mcgill dot ca


http://gcc.gnu.org/bugzilla/show_bug.cgi?id=40074


^ permalink raw reply	[flat|nested] 19+ messages in thread

* [Bug c++/40074] Compile failure in ocrad-0.18
  2009-05-08 20:16 [Bug c++/40074] New: Compile failure in ocrad-0.18 ronis at ronispc dot chem dot mcgill dot ca
@ 2009-05-08 20:17 ` ronis at ronispc dot chem dot mcgill dot ca
  2009-05-08 20:41 ` [Bug tree-optimization/40074] " rguenth at gcc dot gnu dot org
                   ` (16 subsequent siblings)
  17 siblings, 0 replies; 19+ messages in thread
From: ronis at ronispc dot chem dot mcgill dot ca @ 2009-05-08 20:17 UTC (permalink / raw)
  To: gcc-bugs



------- Comment #1 from ronis at ronispc dot chem dot mcgill dot ca  2009-05-08 20:16 -------
Created an attachment (id=17832)
 --> (http://gcc.gnu.org/bugzilla/attachment.cgi?id=17832&action=view)
Preprocessed source of source that triggers ICE


-- 


http://gcc.gnu.org/bugzilla/show_bug.cgi?id=40074


^ permalink raw reply	[flat|nested] 19+ messages in thread

* [Bug tree-optimization/40074] Compile failure in ocrad-0.18
  2009-05-08 20:16 [Bug c++/40074] New: Compile failure in ocrad-0.18 ronis at ronispc dot chem dot mcgill dot ca
  2009-05-08 20:17 ` [Bug c++/40074] " ronis at ronispc dot chem dot mcgill dot ca
@ 2009-05-08 20:41 ` rguenth at gcc dot gnu dot org
  2009-05-08 21:00 ` [Bug tree-optimization/40074] [4.4/4.5 Regression] " rguenth at gcc dot gnu dot org
                   ` (15 subsequent siblings)
  17 siblings, 0 replies; 19+ messages in thread
From: rguenth at gcc dot gnu dot org @ 2009-05-08 20:41 UTC (permalink / raw)
  To: gcc-bugs



------- Comment #2 from rguenth at gcc dot gnu dot org  2009-05-08 20:41 -------
Reducing.


-- 


http://gcc.gnu.org/bugzilla/show_bug.cgi?id=40074


^ permalink raw reply	[flat|nested] 19+ messages in thread

* [Bug tree-optimization/40074] [4.4/4.5 Regression] Compile failure in ocrad-0.18
  2009-05-08 20:16 [Bug c++/40074] New: Compile failure in ocrad-0.18 ronis at ronispc dot chem dot mcgill dot ca
  2009-05-08 20:17 ` [Bug c++/40074] " ronis at ronispc dot chem dot mcgill dot ca
  2009-05-08 20:41 ` [Bug tree-optimization/40074] " rguenth at gcc dot gnu dot org
@ 2009-05-08 21:00 ` rguenth at gcc dot gnu dot org
  2009-05-08 21:00 ` rguenth at gcc dot gnu dot org
                   ` (14 subsequent siblings)
  17 siblings, 0 replies; 19+ messages in thread
From: rguenth at gcc dot gnu dot org @ 2009-05-08 21:00 UTC (permalink / raw)
  To: gcc-bugs



------- Comment #4 from rguenth at gcc dot gnu dot org  2009-05-08 21:00 -------
Created an attachment (id=17833)
 --> (http://gcc.gnu.org/bugzilla/attachment.cgi?id=17833&action=view)
reduced testcase


-- 


http://gcc.gnu.org/bugzilla/show_bug.cgi?id=40074


^ permalink raw reply	[flat|nested] 19+ messages in thread

* [Bug tree-optimization/40074] [4.4/4.5 Regression] Compile failure in ocrad-0.18
  2009-05-08 20:16 [Bug c++/40074] New: Compile failure in ocrad-0.18 ronis at ronispc dot chem dot mcgill dot ca
                   ` (2 preceding siblings ...)
  2009-05-08 21:00 ` [Bug tree-optimization/40074] [4.4/4.5 Regression] " rguenth at gcc dot gnu dot org
@ 2009-05-08 21:00 ` rguenth at gcc dot gnu dot org
  2009-05-09 22:02 ` [Bug tree-optimization/40074] [4.4/4.5 Regression] ICE in vect_get_vec_def_for_operand, at tree-vect-stmts.c:944 hjl dot tools at gmail dot com
                   ` (13 subsequent siblings)
  17 siblings, 0 replies; 19+ messages in thread
From: rguenth at gcc dot gnu dot org @ 2009-05-08 21:00 UTC (permalink / raw)
  To: gcc-bugs



------- Comment #3 from rguenth at gcc dot gnu dot org  2009-05-08 20:59 -------
Confirmed.


-- 

rguenth at gcc dot gnu dot org changed:

           What    |Removed                     |Added
----------------------------------------------------------------------------
                 CC|                            |rguenth at gcc dot gnu dot
                   |                            |org
             Status|UNCONFIRMED                 |NEW
     Ever Confirmed|0                           |1
           Keywords|                            |ice-on-valid-code
      Known to fail|                            |4.4.0
      Known to work|                            |4.3.3
   Last reconfirmed|0000-00-00 00:00:00         |2009-05-08 20:59:57
               date|                            |
            Summary|Compile failure in ocrad-   |[4.4/4.5 Regression] Compile
                   |0.18                        |failure in ocrad-0.18
   Target Milestone|---                         |4.4.1


http://gcc.gnu.org/bugzilla/show_bug.cgi?id=40074


^ permalink raw reply	[flat|nested] 19+ messages in thread

* [Bug tree-optimization/40074] [4.4/4.5 Regression] ICE in vect_get_vec_def_for_operand, at tree-vect-stmts.c:944
  2009-05-08 20:16 [Bug c++/40074] New: Compile failure in ocrad-0.18 ronis at ronispc dot chem dot mcgill dot ca
                   ` (3 preceding siblings ...)
  2009-05-08 21:00 ` rguenth at gcc dot gnu dot org
@ 2009-05-09 22:02 ` hjl dot tools at gmail dot com
  2009-05-09 22:11 ` rguenth at gcc dot gnu dot org
                   ` (12 subsequent siblings)
  17 siblings, 0 replies; 19+ messages in thread
From: hjl dot tools at gmail dot com @ 2009-05-09 22:02 UTC (permalink / raw)
  To: gcc-bugs



------- Comment #5 from hjl dot tools at gmail dot com  2009-05-09 22:02 -------
This is caused by revision 145494:

http://gcc.gnu.org/ml/gcc-cvs/2009-04/msg00115.html


-- 


http://gcc.gnu.org/bugzilla/show_bug.cgi?id=40074


^ permalink raw reply	[flat|nested] 19+ messages in thread

* [Bug tree-optimization/40074] [4.4/4.5 Regression] ICE in vect_get_vec_def_for_operand, at tree-vect-stmts.c:944
  2009-05-08 20:16 [Bug c++/40074] New: Compile failure in ocrad-0.18 ronis at ronispc dot chem dot mcgill dot ca
                   ` (4 preceding siblings ...)
  2009-05-09 22:02 ` [Bug tree-optimization/40074] [4.4/4.5 Regression] ICE in vect_get_vec_def_for_operand, at tree-vect-stmts.c:944 hjl dot tools at gmail dot com
@ 2009-05-09 22:11 ` rguenth at gcc dot gnu dot org
  2009-05-09 22:15 ` hjl dot tools at gmail dot com
                   ` (11 subsequent siblings)
  17 siblings, 0 replies; 19+ messages in thread
From: rguenth at gcc dot gnu dot org @ 2009-05-09 22:11 UTC (permalink / raw)
  To: gcc-bugs



------- Comment #6 from rguenth at gcc dot gnu dot org  2009-05-09 22:10 -------
How can that be if the bug also happens on the 4.4 branch?


-- 


http://gcc.gnu.org/bugzilla/show_bug.cgi?id=40074


^ permalink raw reply	[flat|nested] 19+ messages in thread

* [Bug tree-optimization/40074] [4.4/4.5 Regression] ICE in vect_get_vec_def_for_operand, at tree-vect-stmts.c:944
  2009-05-08 20:16 [Bug c++/40074] New: Compile failure in ocrad-0.18 ronis at ronispc dot chem dot mcgill dot ca
                   ` (5 preceding siblings ...)
  2009-05-09 22:11 ` rguenth at gcc dot gnu dot org
@ 2009-05-09 22:15 ` hjl dot tools at gmail dot com
  2009-05-09 22:31 ` hjl dot tools at gmail dot com
                   ` (10 subsequent siblings)
  17 siblings, 0 replies; 19+ messages in thread
From: hjl dot tools at gmail dot com @ 2009-05-09 22:15 UTC (permalink / raw)
  To: gcc-bugs



------- Comment #7 from hjl dot tools at gmail dot com  2009-05-09 22:15 -------
(In reply to comment #6)
> How can that be if the bug also happens on the 4.4 branch?
> 

The testcase in comment #4 compiles fine with gcc 4.4.1.


-- 


http://gcc.gnu.org/bugzilla/show_bug.cgi?id=40074


^ permalink raw reply	[flat|nested] 19+ messages in thread

* [Bug tree-optimization/40074] [4.4/4.5 Regression] ICE in vect_get_vec_def_for_operand, at tree-vect-stmts.c:944
  2009-05-08 20:16 [Bug c++/40074] New: Compile failure in ocrad-0.18 ronis at ronispc dot chem dot mcgill dot ca
                   ` (6 preceding siblings ...)
  2009-05-09 22:15 ` hjl dot tools at gmail dot com
@ 2009-05-09 22:31 ` hjl dot tools at gmail dot com
  2009-05-09 22:55 ` jakub at gcc dot gnu dot org
                   ` (9 subsequent siblings)
  17 siblings, 0 replies; 19+ messages in thread
From: hjl dot tools at gmail dot com @ 2009-05-09 22:31 UTC (permalink / raw)
  To: gcc-bugs



------- Comment #8 from hjl dot tools at gmail dot com  2009-05-09 22:31 -------
(In reply to comment #1)
> Created an attachment (id=17832)
 --> (http://gcc.gnu.org/bugzilla/attachment.cgi?id=17832&action=view) [edit]
> Preprocessed source of source that triggers ICE
> 

This was introduced between revisions 138059 and 13934.


-- 


http://gcc.gnu.org/bugzilla/show_bug.cgi?id=40074


^ permalink raw reply	[flat|nested] 19+ messages in thread

* [Bug tree-optimization/40074] [4.4/4.5 Regression] ICE in vect_get_vec_def_for_operand, at tree-vect-stmts.c:944
  2009-05-08 20:16 [Bug c++/40074] New: Compile failure in ocrad-0.18 ronis at ronispc dot chem dot mcgill dot ca
                   ` (7 preceding siblings ...)
  2009-05-09 22:31 ` hjl dot tools at gmail dot com
@ 2009-05-09 22:55 ` jakub at gcc dot gnu dot org
  2009-05-10  0:08 ` jakub at gcc dot gnu dot org
                   ` (8 subsequent siblings)
  17 siblings, 0 replies; 19+ messages in thread
From: jakub at gcc dot gnu dot org @ 2009-05-09 22:55 UTC (permalink / raw)
  To: gcc-bugs



------- Comment #9 from jakub at gcc dot gnu dot org  2009-05-09 22:54 -------
The original testcase failure fails with both 4.4.x and trunk and was
introduced between 138524 and 138811.  The reduced testcase only fails on the
trunk, not on the 4.4 branch.


-- 


http://gcc.gnu.org/bugzilla/show_bug.cgi?id=40074


^ permalink raw reply	[flat|nested] 19+ messages in thread

* [Bug tree-optimization/40074] [4.4/4.5 Regression] ICE in vect_get_vec_def_for_operand, at tree-vect-stmts.c:944
  2009-05-08 20:16 [Bug c++/40074] New: Compile failure in ocrad-0.18 ronis at ronispc dot chem dot mcgill dot ca
                   ` (8 preceding siblings ...)
  2009-05-09 22:55 ` jakub at gcc dot gnu dot org
@ 2009-05-10  0:08 ` jakub at gcc dot gnu dot org
  2009-05-10  0:23 ` hjl dot tools at gmail dot com
                   ` (7 subsequent siblings)
  17 siblings, 0 replies; 19+ messages in thread
From: jakub at gcc dot gnu dot org @ 2009-05-10  0:08 UTC (permalink / raw)
  To: gcc-bugs



------- Comment #10 from jakub at gcc dot gnu dot org  2009-05-10 00:08 -------
r138553 in particular.  -O2 -ftree-vectorize -m32 -msse2 is needed to reproduce
it.


-- 


http://gcc.gnu.org/bugzilla/show_bug.cgi?id=40074


^ permalink raw reply	[flat|nested] 19+ messages in thread

* [Bug tree-optimization/40074] [4.4/4.5 Regression] ICE in vect_get_vec_def_for_operand, at tree-vect-stmts.c:944
  2009-05-08 20:16 [Bug c++/40074] New: Compile failure in ocrad-0.18 ronis at ronispc dot chem dot mcgill dot ca
                   ` (9 preceding siblings ...)
  2009-05-10  0:08 ` jakub at gcc dot gnu dot org
@ 2009-05-10  0:23 ` hjl dot tools at gmail dot com
  2009-05-10  9:15 ` rguenth at gcc dot gnu dot org
                   ` (6 subsequent siblings)
  17 siblings, 0 replies; 19+ messages in thread
From: hjl dot tools at gmail dot com @ 2009-05-10  0:23 UTC (permalink / raw)
  To: gcc-bugs



------- Comment #11 from hjl dot tools at gmail dot com  2009-05-10 00:23 -------
It is caused by revision 138553:

http://gcc.gnu.org/ml/gcc-cvs/2008-08/msg00112.html


-- 


http://gcc.gnu.org/bugzilla/show_bug.cgi?id=40074


^ permalink raw reply	[flat|nested] 19+ messages in thread

* [Bug tree-optimization/40074] [4.4/4.5 Regression] ICE in vect_get_vec_def_for_operand, at tree-vect-stmts.c:944
  2009-05-08 20:16 [Bug c++/40074] New: Compile failure in ocrad-0.18 ronis at ronispc dot chem dot mcgill dot ca
                   ` (10 preceding siblings ...)
  2009-05-10  0:23 ` hjl dot tools at gmail dot com
@ 2009-05-10  9:15 ` rguenth at gcc dot gnu dot org
  2009-05-10  9:20 ` irar at il dot ibm dot com
                   ` (5 subsequent siblings)
  17 siblings, 0 replies; 19+ messages in thread
From: rguenth at gcc dot gnu dot org @ 2009-05-10  9:15 UTC (permalink / raw)
  To: gcc-bugs



------- Comment #12 from rguenth at gcc dot gnu dot org  2009-05-10 09:14 -------
Well, that revision only enabled vectorization support for more things...
(which is probably what makes this a regression in the first place).


-- 

rguenth at gcc dot gnu dot org changed:

           What    |Removed                     |Added
----------------------------------------------------------------------------
                 CC|                            |irar at il dot ibm dot com


http://gcc.gnu.org/bugzilla/show_bug.cgi?id=40074


^ permalink raw reply	[flat|nested] 19+ messages in thread

* [Bug tree-optimization/40074] [4.4/4.5 Regression] ICE in vect_get_vec_def_for_operand, at tree-vect-stmts.c:944
  2009-05-08 20:16 [Bug c++/40074] New: Compile failure in ocrad-0.18 ronis at ronispc dot chem dot mcgill dot ca
                   ` (11 preceding siblings ...)
  2009-05-10  9:15 ` rguenth at gcc dot gnu dot org
@ 2009-05-10  9:20 ` irar at il dot ibm dot com
  2009-05-10 11:00 ` irar at il dot ibm dot com
                   ` (4 subsequent siblings)
  17 siblings, 0 replies; 19+ messages in thread
From: irar at il dot ibm dot com @ 2009-05-10  9:20 UTC (permalink / raw)
  To: gcc-bugs



------- Comment #13 from irar at il dot ibm dot com  2009-05-10 09:20 -------
(In reply to comment #12)
> Well, that revision only enabled vectorization support for more things...
> (which is probably what makes this a regression in the first place).

Right, I think it is something in the strided accesses detection. I am looking
into it now.


-- 


http://gcc.gnu.org/bugzilla/show_bug.cgi?id=40074


^ permalink raw reply	[flat|nested] 19+ messages in thread

* [Bug tree-optimization/40074] [4.4/4.5 Regression] ICE in vect_get_vec_def_for_operand, at tree-vect-stmts.c:944
  2009-05-08 20:16 [Bug c++/40074] New: Compile failure in ocrad-0.18 ronis at ronispc dot chem dot mcgill dot ca
                   ` (12 preceding siblings ...)
  2009-05-10  9:20 ` irar at il dot ibm dot com
@ 2009-05-10 11:00 ` irar at il dot ibm dot com
  2009-05-10 16:12 ` hjl dot tools at gmail dot com
                   ` (3 subsequent siblings)
  17 siblings, 0 replies; 19+ messages in thread
From: irar at il dot ibm dot com @ 2009-05-10 11:00 UTC (permalink / raw)
  To: gcc-bugs



------- Comment #14 from irar at il dot ibm dot com  2009-05-10 11:00 -------
I am testing:

Index: tree-vect-data-refs.c
===================================================================
--- tree-vect-data-refs.c       (revision 147329)
+++ tree-vect-data-refs.c       (working copy)
@@ -1424,7 +1424,7 @@ vect_analyze_group_access (struct data_r
       /* First stmt in the interleaving chain. Check the chain.  */
       gimple next = DR_GROUP_NEXT_DR (vinfo_for_stmt (stmt));
       struct data_reference *data_ref = dr;
-      unsigned int count = 1;
+      unsigned int count = 1, gaps = 0;
       tree next_step;
       tree prev_init = DR_INIT (data_ref);
       gimple prev = stmt;
@@ -1490,6 +1490,8 @@ vect_analyze_group_access (struct data_r
                    fprintf (vect_dump, "interleaved store with gaps");
                  return false;
                }
+
+              gaps += diff - 1;
            }

           /* Store the gap from the previous member of the group. If there is
no
@@ -1506,8 +1508,9 @@ vect_analyze_group_access (struct data_r
          the type to get COUNT_IN_BYTES.  */
       count_in_bytes = type_size * count;

-      /* Check that the size of the interleaving is not greater than STEP.  */
-      if (dr_step < count_in_bytes)
+     /* Check that the size of the interleaving (including gaps) is not
greater
+         than STEP.  */
+      if (dr_step && dr_step < count_in_bytes + gaps * type_size)
         {
           if (vect_print_dump_info (REPORT_DETAILS))
             {

It fixes the reduced testcase, but I failed to compile the original one, so
maybe someone could check that the above patch fixes the ICE for the original
testcase?

Thanks,
Ira


-- 

irar at il dot ibm dot com changed:

           What    |Removed                     |Added
----------------------------------------------------------------------------
         AssignedTo|unassigned at gcc dot gnu   |irar at il dot ibm dot com
                   |dot org                     |
             Status|NEW                         |ASSIGNED
   Last reconfirmed|2009-05-08 20:59:57         |2009-05-10 11:00:34
               date|                            |


http://gcc.gnu.org/bugzilla/show_bug.cgi?id=40074


^ permalink raw reply	[flat|nested] 19+ messages in thread

* [Bug tree-optimization/40074] [4.4/4.5 Regression] ICE in vect_get_vec_def_for_operand, at tree-vect-stmts.c:944
  2009-05-08 20:16 [Bug c++/40074] New: Compile failure in ocrad-0.18 ronis at ronispc dot chem dot mcgill dot ca
                   ` (13 preceding siblings ...)
  2009-05-10 11:00 ` irar at il dot ibm dot com
@ 2009-05-10 16:12 ` hjl dot tools at gmail dot com
  2009-05-11 11:54 ` irar at gcc dot gnu dot org
                   ` (2 subsequent siblings)
  17 siblings, 0 replies; 19+ messages in thread
From: hjl dot tools at gmail dot com @ 2009-05-10 16:12 UTC (permalink / raw)
  To: gcc-bugs



------- Comment #15 from hjl dot tools at gmail dot com  2009-05-10 16:11 -------
(In reply to comment #14)
> I am testing:
> 
> Index: tree-vect-data-refs.c
> ===================================================================
> --- tree-vect-data-refs.c       (revision 147329)
> +++ tree-vect-data-refs.c       (working copy)
> @@ -1424,7 +1424,7 @@ vect_analyze_group_access (struct data_r
>        /* First stmt in the interleaving chain. Check the chain.  */
>        gimple next = DR_GROUP_NEXT_DR (vinfo_for_stmt (stmt));
>        struct data_reference *data_ref = dr;
> -      unsigned int count = 1;
> +      unsigned int count = 1, gaps = 0;
>        tree next_step;
>        tree prev_init = DR_INIT (data_ref);
>        gimple prev = stmt;
> @@ -1490,6 +1490,8 @@ vect_analyze_group_access (struct data_r
>                     fprintf (vect_dump, "interleaved store with gaps");
>                   return false;
>                 }
> +
> +              gaps += diff - 1;
>             }
> 
>            /* Store the gap from the previous member of the group. If there is
> no
> @@ -1506,8 +1508,9 @@ vect_analyze_group_access (struct data_r
>           the type to get COUNT_IN_BYTES.  */
>        count_in_bytes = type_size * count;
> 
> -      /* Check that the size of the interleaving is not greater than STEP.  */
> -      if (dr_step < count_in_bytes)
> +     /* Check that the size of the interleaving (including gaps) is not
> greater
> +         than STEP.  */
> +      if (dr_step && dr_step < count_in_bytes + gaps * type_size)
>          {
>            if (vect_print_dump_info (REPORT_DETAILS))
>              {
> 
> It fixes the reduced testcase, but I failed to compile the original one, so
> maybe someone could check that the above patch fixes the ICE for the original
> testcase?
> 

It fixed the original testcase on 4.4 branch.


-- 


http://gcc.gnu.org/bugzilla/show_bug.cgi?id=40074


^ permalink raw reply	[flat|nested] 19+ messages in thread

* [Bug tree-optimization/40074] [4.4/4.5 Regression] ICE in vect_get_vec_def_for_operand, at tree-vect-stmts.c:944
  2009-05-08 20:16 [Bug c++/40074] New: Compile failure in ocrad-0.18 ronis at ronispc dot chem dot mcgill dot ca
                   ` (14 preceding siblings ...)
  2009-05-10 16:12 ` hjl dot tools at gmail dot com
@ 2009-05-11 11:54 ` irar at gcc dot gnu dot org
  2009-05-11 12:34 ` irar at gcc dot gnu dot org
  2009-05-11 12:45 ` irar at il dot ibm dot com
  17 siblings, 0 replies; 19+ messages in thread
From: irar at gcc dot gnu dot org @ 2009-05-11 11:54 UTC (permalink / raw)
  To: gcc-bugs



------- Comment #16 from irar at gcc dot gnu dot org  2009-05-11 11:54 -------
Subject: Bug 40074

Author: irar
Date: Mon May 11 11:54:02 2009
New Revision: 147370

URL: http://gcc.gnu.org/viewcvs?root=gcc&view=rev&rev=147370
Log:
        PR tree-optimization/40074
        * tree-vect-analyze.c (vect_analyze_group_access): Take gaps into
        account in group size and step comparison.


Added:
    branches/gcc-4_4-branch/gcc/testsuite/gcc.dg/vect/pr40074.c
Modified:
    branches/gcc-4_4-branch/gcc/ChangeLog
    branches/gcc-4_4-branch/gcc/testsuite/ChangeLog
    branches/gcc-4_4-branch/gcc/tree-vect-analyze.c


-- 


http://gcc.gnu.org/bugzilla/show_bug.cgi?id=40074


^ permalink raw reply	[flat|nested] 19+ messages in thread

* [Bug tree-optimization/40074] [4.4/4.5 Regression] ICE in vect_get_vec_def_for_operand, at tree-vect-stmts.c:944
  2009-05-08 20:16 [Bug c++/40074] New: Compile failure in ocrad-0.18 ronis at ronispc dot chem dot mcgill dot ca
                   ` (15 preceding siblings ...)
  2009-05-11 11:54 ` irar at gcc dot gnu dot org
@ 2009-05-11 12:34 ` irar at gcc dot gnu dot org
  2009-05-11 12:45 ` irar at il dot ibm dot com
  17 siblings, 0 replies; 19+ messages in thread
From: irar at gcc dot gnu dot org @ 2009-05-11 12:34 UTC (permalink / raw)
  To: gcc-bugs



------- Comment #17 from irar at gcc dot gnu dot org  2009-05-11 12:33 -------
Subject: Bug 40074

Author: irar
Date: Mon May 11 12:33:13 2009
New Revision: 147372

URL: http://gcc.gnu.org/viewcvs?root=gcc&view=rev&rev=147372
Log:
        PR tree-optimization/40074
        * tree-vect-data-refs.c (vect_analyze_group_access): Take gaps into
        account in group size and step comparison.


Added:
    trunk/gcc/testsuite/gcc.dg/vect/pr40074.c
Modified:
    trunk/gcc/ChangeLog
    trunk/gcc/testsuite/ChangeLog
    trunk/gcc/tree-vect-data-refs.c


-- 


http://gcc.gnu.org/bugzilla/show_bug.cgi?id=40074


^ permalink raw reply	[flat|nested] 19+ messages in thread

* [Bug tree-optimization/40074] [4.4/4.5 Regression] ICE in vect_get_vec_def_for_operand, at tree-vect-stmts.c:944
  2009-05-08 20:16 [Bug c++/40074] New: Compile failure in ocrad-0.18 ronis at ronispc dot chem dot mcgill dot ca
                   ` (16 preceding siblings ...)
  2009-05-11 12:34 ` irar at gcc dot gnu dot org
@ 2009-05-11 12:45 ` irar at il dot ibm dot com
  17 siblings, 0 replies; 19+ messages in thread
From: irar at il dot ibm dot com @ 2009-05-11 12:45 UTC (permalink / raw)
  To: gcc-bugs



------- Comment #18 from irar at il dot ibm dot com  2009-05-11 12:45 -------
Fixed.


-- 

irar at il dot ibm dot com changed:

           What    |Removed                     |Added
----------------------------------------------------------------------------
             Status|ASSIGNED                    |RESOLVED
         Resolution|                            |FIXED


http://gcc.gnu.org/bugzilla/show_bug.cgi?id=40074


^ permalink raw reply	[flat|nested] 19+ messages in thread

end of thread, other threads:[~2009-05-11 12:45 UTC | newest]

Thread overview: 19+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2009-05-08 20:16 [Bug c++/40074] New: Compile failure in ocrad-0.18 ronis at ronispc dot chem dot mcgill dot ca
2009-05-08 20:17 ` [Bug c++/40074] " ronis at ronispc dot chem dot mcgill dot ca
2009-05-08 20:41 ` [Bug tree-optimization/40074] " rguenth at gcc dot gnu dot org
2009-05-08 21:00 ` [Bug tree-optimization/40074] [4.4/4.5 Regression] " rguenth at gcc dot gnu dot org
2009-05-08 21:00 ` rguenth at gcc dot gnu dot org
2009-05-09 22:02 ` [Bug tree-optimization/40074] [4.4/4.5 Regression] ICE in vect_get_vec_def_for_operand, at tree-vect-stmts.c:944 hjl dot tools at gmail dot com
2009-05-09 22:11 ` rguenth at gcc dot gnu dot org
2009-05-09 22:15 ` hjl dot tools at gmail dot com
2009-05-09 22:31 ` hjl dot tools at gmail dot com
2009-05-09 22:55 ` jakub at gcc dot gnu dot org
2009-05-10  0:08 ` jakub at gcc dot gnu dot org
2009-05-10  0:23 ` hjl dot tools at gmail dot com
2009-05-10  9:15 ` rguenth at gcc dot gnu dot org
2009-05-10  9:20 ` irar at il dot ibm dot com
2009-05-10 11:00 ` irar at il dot ibm dot com
2009-05-10 16:12 ` hjl dot tools at gmail dot com
2009-05-11 11:54 ` irar at gcc dot gnu dot org
2009-05-11 12:34 ` irar at gcc dot gnu dot org
2009-05-11 12:45 ` irar at il dot ibm dot com

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).